
Changelog
=========

0.0.2 (2023-07-12)
~~~~~~~~~~~~~~~~~~


* Bug fixes
* Enhanced error handling
* Improved method attributes
* Added the ability to print the query string
* Implemented a feature to handle queries with large limits
* NEW: Introduced a web interface for the API, making it even easier to use


0.0.1 (2023-07-09)
~~~~~~~~~~~~~~~~~~

* First release on PyPI.
